@@ -28,11 +28,10 @@ specified by `Coverage Config
 However, when doing so you should also be aware of
 `Differences From coverage`_.
 """
-from __future__ import absolute_import, print_function
 
+import io
 import logging
 
-import six
 from nose2.events import Plugin
 
 log = logging.getLogger(__name__)
@@ -49,7 +48,7 @@ class Coverage(Plugin):
         # tracking var for any decision which marks the entire run as failed
         self.decided_failure = False
         # buffer for error output data
-        self.error_output_buffer = six.StringIO()
+        self.error_output_buffer = io.StringIO()
 
         self.covSource = self.config.as_list("coverage", []) or ["."]
         self.covReport = self.config.as_list("coverage-report", []) or ["term"]
